@@ -2,4 +2,6 @@ from pygame_widgets.textbox import TextBox
 from pygame_widgets.button import Button, ButtonArray
 from pygame_widgets.slider import Slider
 from pygame_widgets.animations.animation import AnimationBase, Translate, Resize
-from pygame_widgets.dropdown import Dropdown
\ No newline at end of file
+from pygame_widgets.dropdown import Dropdown
+from pygame_widgets.toggle import Toggle
+from pygame_widgets.progressbar import ProgressBar
